@@ -23,7 +23,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QDebug>
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber operator+(const KNumber &lhs, const KNumber &rhs) {
 	KNumber x(lhs);
@@ -32,7 +32,7 @@ KNumber operator+(const KNumber &lhs, const KNumber &rhs) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber operator-(const KNumber &lhs, const KNumber &rhs) {
 	KNumber x(lhs);
@@ -41,7 +41,7 @@ KNumber operator-(const KNumber &lhs, const KNumber &rhs) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber operator*(const KNumber &lhs, const KNumber &rhs) {
 	KNumber x(lhs);
@@ -50,7 +50,7 @@ KNumber operator*(const KNumber &lhs, const KNumber &rhs) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber operator/(const KNumber &lhs, const KNumber &rhs) {
 	KNumber x(lhs);
@@ -59,7 +59,7 @@ KNumber operator/(const KNumber &lhs, const KNumber &rhs) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber operator%(const KNumber &lhs, const KNumber &rhs) {
 	KNumber x(lhs);
@@ -68,7 +68,7 @@ KNumber operator%(const KNumber &lhs, const KNumber &rhs) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber operator&(const KNumber &lhs, const KNumber &rhs) {
 	KNumber x(lhs);
@@ -77,7 +77,7 @@ KNumber operator&(const KNumber &lhs, const KNumber &rhs) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber operator|(const KNumber &lhs, const KNumber &rhs) {
 	KNumber x(lhs);
@@ -86,7 +86,7 @@ KNumber operator|(const KNumber &lhs, const KNumber &rhs) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber operator^(const KNumber &lhs, const KNumber &rhs) {
 	KNumber x(lhs);
@@ -95,7 +95,7 @@ KNumber operator^(const KNumber &lhs, const KNumber &rhs) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber operator>>(const KNumber &lhs, const KNumber &rhs) {
 	KNumber x(lhs);
@@ -104,7 +104,7 @@ KNumber operator>>(const KNumber &lhs, const KNumber &rhs) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber operator<<(const KNumber &lhs, const KNumber &rhs) {
 	KNumber x(lhs);
@@ -113,161 +113,183 @@ KNumber operator<<(const KNumber &lhs, const KNumber &rhs) {
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber abs(const KNumber &x) {
 	return x.abs();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber cbrt(const KNumber &x) {
 	return x.cbrt();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber sqrt(const KNumber &x) {
 	return x.sqrt();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber sin(const KNumber &x) {
 	return x.sin();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber cos(const KNumber &x) {
 	return x.cos();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber tan(const KNumber &x) {
 	return x.tan();
 }
 
+
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber asin(const KNumber &x) {
 	return x.asin();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber acos(const KNumber &x) {
 	return x.acos();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
+//------------------------------------------------------------------------------
+KNumber tgamma(const KNumber &x) {
+	return x.tgamma();
+}
+
+//------------------------------------------------------------------------------
+// Name:
 //------------------------------------------------------------------------------
 KNumber atan(const KNumber &x) {
 	return x.atan();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber pow(const KNumber &x, const KNumber &y) {
 	return x.pow(y);
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber factorial(const KNumber &x) {
 	return x.factorial();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber log2(const KNumber &x) {
 	return x.log2();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
+//------------------------------------------------------------------------------
+KNumber floor(const KNumber &x) {
+	return x.floor();
+}
+
+//------------------------------------------------------------------------------
+// Name:
+//------------------------------------------------------------------------------
+KNumber ceil(const KNumber &x) {
+	return x.ceil();
+}
+
+//------------------------------------------------------------------------------
+// Name:
 //------------------------------------------------------------------------------
 KNumber log10(const KNumber &x) {
 	return x.log10();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber ln(const KNumber &x) {
 	return x.ln();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber exp2(const KNumber &x) {
 	return x.exp2();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber exp10(const KNumber &x) {
 	return x.exp10();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 KNumber exp(const KNumber &x) {
 	return x.exp();
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 bool operator==(const KNumber &lhs, const KNumber &rhs) {
 	return lhs.value_->compare(rhs.value_) == 0;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 bool operator!=(const KNumber &lhs, const KNumber &rhs) {
 	return lhs.value_->compare(rhs.value_) != 0;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 bool operator>=(const KNumber &lhs, const KNumber &rhs) {
 	return lhs.value_->compare(rhs.value_) >= 0;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 bool operator<=(const KNumber &lhs, const KNumber &rhs) {
 	return lhs.value_->compare(rhs.value_) <= 0;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 bool operator>(const KNumber &lhs, const KNumber &rhs) {
 	return lhs.value_->compare(rhs.value_) > 0;
 }
 
 //------------------------------------------------------------------------------
-// Name: 
+// Name:
 //------------------------------------------------------------------------------
 bool operator<(const KNumber &lhs, const KNumber &rhs) {
 	return lhs.value_->compare(rhs.value_) < 0;
