@@ -49,6 +49,7 @@ KNumber sin(const KNumber &x);
 KNumber cos(const KNumber &x);
 KNumber tan(const KNumber &x);
 KNumber asin(const KNumber &x);
+KNumber tgamma(const KNumber &x);
 KNumber acos(const KNumber &x);
 KNumber atan(const KNumber &x);
 
@@ -56,6 +57,8 @@ KNumber factorial(const KNumber &x);
 
 KNumber log2(const KNumber &x);
 KNumber log10(const KNumber &x);
+KNumber ceil(const KNumber &x);
+KNumber floor(const KNumber &x);
 KNumber ln(const KNumber &x);
 KNumber exp2(const KNumber &x);
 KNumber exp10(const KNumber &x);
